Repository: flex-sdk
Updated Branches:
  refs/heads/release4.14.0 7a0515845 -> fef7f0683


Revert "Merge commit '1884960242f835879f5ca6504659072a2305f120' into 
release4.14.0"

This reverts commit 7a051584552d332fc27e743b6ef83864a0737e53, reversing
changes made to 1884960242f835879f5ca6504659072a2305f120.


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/fef7f068
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/fef7f068
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/fef7f068

Branch: refs/heads/release4.14.0
Commit: fef7f068389de417435e5471a00dfbbd3fd9a974
Parents: 7a05158
Author: OmPrakash Muppirala <[email protected]>
Authored: Mon Dec 15 17:43:09 2014 -0800
Committer: OmPrakash Muppirala <[email protected]>
Committed: Mon Dec 15 17:43:09 2014 -0800

----------------------------------------------------------------------
 CONTRIBUTORS                                    | 10 +--
 NOTICE                                          |  4 +
 README                                          | 41 +++++----
 RELEASE_NOTES                                   | 91 ++++++++++----------
 build.properties                                |  6 +-
 build.xml                                       |  3 +-
 flex-sdk-description.xml                        |  4 +-
 frameworks/build.xml                            |  3 -
 frameworks/flex-config.xml                      |  2 +-
 .../advancedgrids/src/mx/core/Version.as        |  2 +-
 .../airframework/src/mx/core/Version.as         |  2 +-
 .../projects/airspark/src/spark/core/Version.as |  2 +-
 frameworks/projects/apache/src/core/Version.as  |  2 +-
 .../projects/automation/src/mx/core/Version.as  |  2 +-
 .../automation_agent/src/mx/core/Version.as     |  2 +-
 .../automation_air/src/mx/core/Version.as       |  2 +-
 .../automation_dmv/src/mx/core/Version.as       |  2 +-
 .../src/mx/core/Version.as                      |  2 +-
 .../automation_spark/src/mx/core/Version.as     |  2 +-
 .../automation_spark/src/spark/core/Version.as  |  2 +-
 .../projects/charts/src/mx/core/Version.as      |  2 +-
 .../projects/framework/src/FrameworkClasses.as  |  1 -
 .../framework/src/mx/core/FlexVersion.as        | 16 +---
 .../projects/framework/src/mx/core/Version.as   |  2 +-
 .../src/mx/resources/ResourceManagerImpl.as     |  3 -
 .../src/mx/utils/LegacyMobileThemeOverride.as   | 47 ----------
 frameworks/projects/mobiletheme/defaults.css    |  3 +-
 frameworks/projects/mx/src/mx/core/Version.as   |  2 +-
 frameworks/projects/rpc/src/mx/core/Version.as  |  2 +-
 .../projects/spark/src/spark/core/Version.as    |  2 +-
 .../spark_dmv/src/spark/core/Version.as         |  2 +-
 frameworks/projects/tool/src/mx/core/Version.as |  2 +-
 .../projects/tool_air/src/mx/core/Version.as    |  2 +-
 ide/addAIRtoSDK.sh                              | 16 +---
 ide/checkAllPlayerGlobals.sh                    | 34 ++++----
 ide/constructFlexForIDE.sh                      |  2 -
 ide/flashbuilder/config/air-config.xml          | 20 ++---
 ide/flashbuilder/config/flex-config.xml         | 22 ++---
 ide/flashbuilder/makeApacheFlexForIDE.bat       | 16 ++--
 ide/flashbuilder/makeApacheFlexForIDE.sh        | 14 +--
 ide/setFlashPlayerVersion.sh                    | 30 ++-----
 jenkins.xml                                     | 32 +------
 .../compiler/common/MxmlConfiguration.java      |  5 +-
 .../src/java/flex2/tools/VersionInfo.java       |  2 +-
 mustella/jenkins.sh                             | 12 +--
 .../ResourceManager_Methods_getString.mxml      | 13 ---
 46 files changed, 171 insertions(+), 319 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/CONTRIBUTORS
----------------------------------------------------------------------
diff --git a/CONTRIBUTORS b/CONTRIBUTORS
index b865201..ec78d55 100644
--- a/CONTRIBUTORS
+++ b/CONTRIBUTORS
@@ -3,12 +3,10 @@ support to the Apache Flex SDK.
 
 Apache Flex SDK 4.14.0
 ----------------------
-Aaron Nash, Ad Pijnenburg, After24, Alex Harui, Andras Janurik, Anthony,
-Chris Martin, Christofer Dutz, Curtis Aube, Darrell Loverin,  Dimitri Kara,
-Erik de Bruin, Frédéric Thomas, Gareth Daniel Smith, Jeff Spicer, Jorn 
Nolles,
-Justin Mclean, Keith Lee, Lee Burrows, Mahmoud Ali, Marcus Wilkinson,
-Mark Kessler, Mihai Chira, Neil Madsen, OmPrakash Muppirala, Peter Volf,
-Shigeru Nakagaki, Stefan Overkamp, Tom Chiverton, Vadim Usoltsev, Vitaliy 
Parfenov
+Aaron Nash, After24, Alex Harui, Chris Martin, Curtis Aube, Darrell Loverin, 
+Erik de Bruin, Frédéric Thomas, Gareth Daniel Smith, Justin Mclean, Lee 
Burrows,
+Mahmoud Ali, Marcus Wilkinson, Mark Kessler, Mihai Chira, Neil Madsen, 
+OmPrakash Muppirala, Tom Chiverton
 
 Apache Flex SDK 4.13.0
 ----------------------

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/NOTICE
----------------------------------------------------------------------
diff --git a/NOTICE b/NOTICE
index cc7fad8..5aa5688 100644
--- a/NOTICE
+++ b/NOTICE
@@ -22,3 +22,7 @@ Definition (DTD).
 The Batik SVG toolkit source contains code from the International Organisation
 for Standardization for the definition of character entities used in the
 software's documentation.
+
+The Open Source Media Framework used by the video components is licensed under
+the Mozilla Public License Version 1.1. The source code can be found here:
+    
http://sourceforge.net/projects/osmf.adobe/files/OSMF%201.0%20%28final%20source%2C%20ASDocs%2C%20PDF%20guides%2C%20and%20release%20notes%29/OSMF_1.0.zip

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/README
----------------------------------------------------------------------
diff --git a/README b/README
index 43efd44..20449b2 100644
--- a/README
+++ b/README
@@ -90,10 +90,9 @@ bundled with the Apache Flex SDK, i.e. they need to be 
installed separately.
 The Adobe Flash Player ‘playerglobal.swc’ is needed to compile all the
 components with the exception of the ‘airframework’ and ‘airspark’
 components which require ‘airglobal.swc’ from the AIR Integration Kit. The
-AIR Integration kit is also needed to build and debug mobile and desktop
-applications. The Adobe Flash Player content debugger is used by the ant
-‘checkintests’ target and other pieces of the test subsystem to run 
compiled
-applications.
+AIR Integration kit is also needed to build and debug mobile applications. The
+Adobe Flash Player content debugger is used by the ant ‘checkintests’
+target and other pieces of the test subsystem to run compiled applications.
 
 
 ---------------------------------------------------------------------
@@ -155,7 +154,7 @@ The Adobe AIR integration kit for Linux can be downloaded 
from:
 Download the AIR SDK for your platform and unzip it. Set AIR_HOME to the
 absolute path of the AIR SDK directory.
 
-This version of the Apache Flex SDK was certified for use with Adobe AIR 15
+This version of the Apache Flex SDK was certified for use with Adobe AIR 3.7
 and is compatible with version 3.1 and up. It has been fully tested on AIR 3.7,
 4 and 15.
 
@@ -317,19 +316,18 @@ need to run these commands and scripts:
     cd <flex.dir>
     ant frameworks-rsls
     ./ide/constructFlexForIDE.[sh/bat]
+    (Mac only: ./ide/addAIRtoSDK.sh)
 
 This builds the RSLS for the SDK and copy some IDE related files from the Adobe
-Flex SDK 4.6.
+Flex SDK 4.6. On a Mac you will need to run the 'addAIRtoSDK.sh' script to
+complete the installation.
 
 To create an SDK for another IDE, or if you want to use a different version of
 Adobe AIR (Adobe Flex 4.6 uses Adobe AIR 3.1), run:
 
-    ./ide/flashbuilder/makeApacheFlexForIDE.bat (on Windows)
-    ./ide/flashbuilder/makeApacheFlexForIDE.sh (on Mac and Linux)
+    /ide/flashbuilder/makeApacheFlexForIDE.bat (on Windows)
+    /ide/flashbuilder/makeApacheFlexForIDE.sh (on Mac and Linux)
 
-On Mac the AIR and Flash Player version can be changed by running:
-       ./ide/setFlashPlayerVersion.sh
-       ./ide/addAIRtoSDK.sh
 
 
 Using the Binary Distribution
@@ -418,9 +416,9 @@ OR
 Change the playerglobal.version in the build.properties file to have a value
 other than '11.1'. For this change to take effect the SDK needs to be
 recompiled. For example to compile against the latest version of the Adobe
-Flash Player set the value of playerglobal.version to be '15.0' like so:
+Flash Player set the value of playerglobal.version to be '14.0' like so:
 
-    playerglobal.version = 15.0
+    playerglobal.version = 14.0
 
 OR
 
@@ -437,18 +435,17 @@ These can be found at:
 
 and
 
-    
http://download.macromedia.com/get/flashplayer/updaters/<version.major>/playerglobal<version.major>_<version.minor>.swc
+   
http://download.macromedia.com/get/flashplayer/updaters/<version.major>/playerglobal<version.major>_<version.minor>.swc
 
 (e.g. 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc)
 
 Copy the target playerglobal.swc to the directory:
 
-    frameworks/libs/player/<version.major>.<version.minor>/playerglobal.swc
-    
-On OSX runing the script:
-    ./ide/checkAllPlayerGlobals.sh 
- 
- Will download any new or missing player global swcs.
+    frameworks/libs/player/<version>/playerglobal.swc
+
+Where <version> is the major and minor version numbers of the Adobe Flash
+Player separated by a period or full stop.
+
 
 Software Dependencies
 =====================
@@ -458,6 +455,8 @@ the build. In addition, there is some optional third-party 
code that you can
 choose to download if you would like to take advantage of the features offered
 and you agree to the license terms.
 
+The Apache Version 2.0 license is in the LICENSE file.
+
 The following dependencies have licenses which are, or are compatible with, the
 Apache Version 2.0 license. You will not be prompted to acknowledge the
 download. Most of the jars are installed in lib/external.
@@ -477,7 +476,7 @@ reciprocal licenses so you will be prompted to acknowledge 
the license before
 the software is downloaded to your system. These files are installed in
 frameworks/libs.
 
-    osmf.swc (Open Source Media Framework v2.0; used for video components)
+    osmf.swc (Open Source Media Framework v1.0; used for video components)
 
     This file is extracted from:
 

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/RELEASE_NOTES
----------------------------------------------------------------------
diff --git a/RELEASE_NOTES b/RELEASE_NOTES
index 23134fb..9e1d765 100644
--- a/RELEASE_NOTES
+++ b/RELEASE_NOTES
@@ -11,74 +11,71 @@ New Features
 
 AIR and Flash Player Support
 ----------------------------
-- Support Flash Player 15.0 and 16.0 beta
-- Support for AIR 15.0 and 16.0 beta
+- Support Flash Player 15.0
+- Support for AIR 15.0
 
 Bug Fixes
 ---------
-FLEX-34649  (partial) Fatal errors in TextBlock after pasting text of specific
+FLEX-34649  (partial) Fatal errors in TextBlock after pasting text of specific 
             length in TextArea
+FLEX-34507  expected build.xml file missing from Linux binary tarball 
+            apache-flex-sdk-4.13.0-bin.tar.gz
+FLEX-34336  Strange Trace Statements When Debugging
+FLEX-34631  Cannot add source paths to a mustella test using a config file
 FLEX-34644  Datagrid - Rectangle bounds problem
-FLEX-34636  Release build does not work as described in README on OS X
-FLEX-34634  DataGroup fires RendererExistenceEvent with a null renderer when an
-            offscreen item is removed/replaced in the dataProvider
+FLEX-34454  Setting modalTransparencyBlur to 0 gives blur when Alert ist shown
+            on top of modal Dialog
+FLEX-34373  spark.components.Alert should set a focus to defaultButton
+FLEX-34557  Platform.isBrowser does not work correctly
+FLEX-34213  Flex mobile list performance
+FLEX-34531  mx.charts.series.HLOCSeries excluding a style being used in example
+FLEX-34476  Added RichTextEditor
+FLEX-34323  Allow the mustella tests directory to be located anywhere
+FLEX-34460  adt is missing in windows install
 FLEX-34633  HSlider track (Android4 skin) not being filled if thumb position 
set
-            in one case, text selection using the arrow keys doesn't work in
+            programmatically
+FLEX-34457  in one case, text selection using the arrow keys doesn't work in
             RichEditableText
-FLEX-34631  Cannot add source paths to a mustella test using a config file
+FLEX-34634  DataGroup fires RendererExistenceEvent with a null renderer when an
+            offscreen item is removed/replaced in the dataProvider
+FLEX-34636  Release build does not work as described in README on OS X
+FLEX-34543  Invalid event data when saving or cancelling grid item editor
+            session after data provider changes
+FLEX-28291  Linear Vector Layout on the ComboBox
+FLEX-34212  invalidIndex RTE in LinearLayoutVector when mouse scrolling List
+FLEX-34608  IOS 7 Hslider (Scrubber) skin
 FLEX-34611  Application crash when textFlow property set to null with
             preserveSelection
-FLEX-34608  IOS 7 Hslider (Scrubber) skin
 FLEX-34606  Redundant variable
 FLEX-34592  Can't use optionnal importer for TLF plainTextFormat and
             TextLayoutFormat
-FLEX-34557  Platform.isBrowser does not work correctly
-FLEX-34556  Starting an app in portrait on an iPad results in wrong DPI
-FLEX-34543  Invalid event data when saving or cancelling grid item editor
-            session after data provider changes
-FLEX-34539  Callout skin assumes top level application is s:Application
+FLEX-34390  SkinnableTextBase bug (found in Flex 4.13.0 RC2)
 FLEX-34538  Spark Alert component does not add proper padding
-FLEX-34531  mx.charts.series.HLOCSeries excluding a style being used in example
-FLEX-34507  expected build.xml file missing from Linux binary tarball
-            apache-flex-sdk-4.13.0-bin.tar.gz
-FLEX-34476  Added RichTextEditor
-FLEX-34467  Spark DataGrid performance extremely decreased since "gridView" is 
-            introduced
-FLEX-34460  adt is missing in windows install
+FLEX-34539  Callout skin assumes top level application is s:Application
+FLEX-34556  Starting an app in portrait on an iPad results in wrong DPI
+FLEX-34318  [Mavenizer] Refactor the Mavenizer in preparation of future
+            mavenized releases of flex
 FLEX-34458  HierarchicalCollectionViewCursor.current returns wrong item after
             previous sibling is removed when current was "${L}"
             (CursorBookmark.LAST)
-FLEX-34456  HierarchicalCollectionViewCursors interfere with each other's
-            operation
-FLEX-34454  Setting modalTransparencyBlur to 0 gives blur when Alert ist shown
-            on top of modal Dialog
-FLEX-34450  mx.validators.EmailValidator does not accept ".email" domain
-FLEX-34440  'Bookmark no longer valid' CursorError caused by
-            HierarchicalCollectionView's conversion of
-            CollectionEventKind.REPLACE into CollectionEventKind.REMOVE
-FLEX-34424  HierarchicalCollectionViewCursor.current returns null when previous
-            sibling is removed
-FLEX-34390  SkinnableTextBase bug (found in Flex 4.13.0 RC2)
 FLEX-34385  Document try..catch limitation
-FLEX-34378  mx:DateValidator allows multiple separator chars
-FLEX-34373  spark.components.Alert should set a focus to defaultButton
-FLEX-34336  Strange Trace Statements When Debugging
-FLEX-34323  Allow the mustella tests directory to be located anywhere
-FLEX-34318  [Mavenizer] Refactor the Mavenizer in preparation of future
-            mavenized releases of flex
-FLEX-34260  s:datagrid cacheAsBitmap caches an itemRenderer for every item in 
-            the dataProvider
-FLEX-34213  Flex mobile list performance
-FLEX-34212  invalidIndex RTE in LinearLayoutVector when mouse scrolling List
 FLEX-34119  mx.collections.HierarchicalCollectionViewCursor causes CursorError
             RTE from ListCollectionView when the underlying collections change
-FLEX-34034  You can paste a newline code to a single-line TextInput.
+FLEX-32541  sortable ou sortableColumns = false still shows box of sorting and 
+            sortItemRenderer = null throws error
 FLEX-33732  Mobile theme support Android 4.x look and feel
-FLEX-33054  Cursor Seek in HierarchicalCollectionViewCursor operates on wrong
+FLEX-34424  HierarchicalCollectionViewCursor.current returns null when 
previous 
+            sibling is removed
+FLEX-34456  HierarchicalCollectionViewCursors interfere with each other's 
+            operation
+FLEX-33054  Cursor Seek in HierarchicalCollectionViewCursor operates on wrong 
             child level
-FLEX-32541  sortable ou sortableColumns = false still shows box of sorting and
-            sortItemRenderer = null throws error
-FLEX-28291  Linear Vector Layout on the ComboBox
+FLEX-34440  'Bookmark no longer valid' CursorError caused by 
+            HierarchicalCollectionView's conversion of 
+            CollectionEventKind.REPLACE into CollectionEventKind.REMOVE
+FLEX-34034  You can paste a newline code to a single-line TextInput.
+FLEX-34450  mx.validators.EmailValidator does not accept ".email" domain
+FLEX-34378  mx:DateValidator allows multiple separator chars
 
 Other fixes (no JIRA issue created):
 - correct case for osmf.swc so compiles on Linux work

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/build.properties
----------------------------------------------------------------------
diff --git a/build.properties b/build.properties
index c7e0c2c..35fd073 100644
--- a/build.properties
+++ b/build.properties
@@ -18,8 +18,8 @@
 
################################################################################
 
 # flex-sdk-description values
-release = Apache Flex 4.15.0
-release.version = 4.15.0
+release = Apache Flex 4.14.0
+release.version = 4.14.0
 
 # override on command line with -Dbuild.number=999 or in local.properties
 build.number = 0
@@ -28,7 +28,7 @@ build.number = 0
 playerglobal.version = 11.1
 
 # AIR version number
-air.version = 15.0
+air.version = 14.0
 
 # Default locale for the SDK
 locale = en_US

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/build.xml
----------------------------------------------------------------------
diff --git a/build.xml b/build.xml
index 36a29e2..569248f 100644
--- a/build.xml
+++ b/build.xml
@@ -897,7 +897,7 @@ There are no known issues.
         
         <antcall target="stage-source"/>
         
-        <!--
+        <!-- 
             Some, but not all framework sources are included.
             Need to include the sources required for build_framework.xml.
         -->
@@ -973,7 +973,6 @@ There are no known issues.
                 <include name="core.swc"/>
                <include name="experimental.swc"/>
                <include name="experimental_mobile.swc"/>
-                <include name="flatspark.swc"/>
                 <include name="spark.swc"/>
                 <include name="framework.swc"/>
                 <include name="mx/mx.swc"/>

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/flex-sdk-description.xml
----------------------------------------------------------------------
diff --git a/flex-sdk-description.xml b/flex-sdk-description.xml
index 231303c..e752185 100644
--- a/flex-sdk-description.xml
+++ b/flex-sdk-description.xml
@@ -18,8 +18,8 @@
 
 -->
 <flex-sdk-description>
-<name>Apache Flex 4.14.0 FP11.1 AIR15.0 en_US</name>
-<version>4.14.0</version>
+<name>Apache Flex 4.13.0 FP11.1 AIR3.9 en_US</name>
+<version>4.13.0</version>
 <build>0</build>
 </flex-sdk-description>
         
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/build.xml
----------------------------------------------------------------------
diff --git a/frameworks/build.xml b/frameworks/build.xml
index f44f73a..541f92f 100644
--- a/frameworks/build.xml
+++ b/frameworks/build.xml
@@ -214,9 +214,6 @@
                <condition property="playerglobal.swfversion" value="26">
                        <equals arg1="${playerglobal.version}" arg2="15.0" />
                </condition>
-               <condition property="playerglobal.swfversion" value="27">
-                       <equals arg1="${playerglobal.version}" arg2="16.0" />
-               </condition>
        </target>       
 
     <!--

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/flex-config.xml
----------------------------------------------------------------------
diff --git a/frameworks/flex-config.xml b/frameworks/flex-config.xml
index 7092b13..2797eeb 100644
--- a/frameworks/flex-config.xml
+++ b/frameworks/flex-config.xml
@@ -406,7 +406,7 @@
            Flex Library project, FlashBuilder will allow "Link Type" to be 
external.
     -->
     <runtime-shared-library-path>
-               <path-element>libs/osmf.swc</path-element>
+               <path-element>libs/OSMF.swc</path-element>
                <rsl-url>osmf_${build.number}.swf</rsl-url>
        </runtime-shared-library-path>
 

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/advancedgrids/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/advancedgrids/src/mx/core/Version.as 
b/frameworks/projects/advancedgrids/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/advancedgrids/src/mx/core/Version.as
+++ b/frameworks/projects/advancedgrids/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/airframework/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/airframework/src/mx/core/Version.as 
b/frameworks/projects/airframework/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/airframework/src/mx/core/Version.as
+++ b/frameworks/projects/airframework/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/airspark/src/spark/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/airspark/src/spark/core/Version.as 
b/frameworks/projects/airspark/src/spark/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/airspark/src/spark/core/Version.as
+++ b/frameworks/projects/airspark/src/spark/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/apache/src/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/apache/src/core/Version.as 
b/frameworks/projects/apache/src/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/apache/src/core/Version.as
+++ b/frameworks/projects/apache/src/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation/src/mx/core/Version.as 
b/frameworks/projects/automation/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/automation/src/mx/core/Version.as
+++ b/frameworks/projects/automation/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation_agent/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation_agent/src/mx/core/Version.as 
b/frameworks/projects/automation_agent/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/automation_agent/src/mx/core/Version.as
+++ b/frameworks/projects/automation_agent/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation_air/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation_air/src/mx/core/Version.as 
b/frameworks/projects/automation_air/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/automation_air/src/mx/core/Version.as
+++ b/frameworks/projects/automation_air/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation_dmv/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation_dmv/src/mx/core/Version.as 
b/frameworks/projects/automation_dmv/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/automation_dmv/src/mx/core/Version.as
+++ b/frameworks/projects/automation_dmv/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation_flashflexkit/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation_flashflexkit/src/mx/core/Version.as 
b/frameworks/projects/automation_flashflexkit/src/mx/core/Version.as
index 4f4cefa..8d74c4e 100644
--- a/frameworks/projects/automation_flashflexkit/src/mx/core/Version.as
+++ b/frameworks/projects/automation_flashflexkit/src/mx/core/Version.as
@@ -24,4 +24,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation_spark/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation_spark/src/mx/core/Version.as 
b/frameworks/projects/automation_spark/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/automation_spark/src/mx/core/Version.as
+++ b/frameworks/projects/automation_spark/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/automation_spark/src/spark/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/automation_spark/src/spark/core/Version.as 
b/frameworks/projects/automation_spark/src/spark/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/automation_spark/src/spark/core/Version.as
+++ b/frameworks/projects/automation_spark/src/spark/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/charts/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/charts/src/mx/core/Version.as 
b/frameworks/projects/charts/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/charts/src/mx/core/Version.as
+++ b/frameworks/projects/charts/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/framework/src/FrameworkClasses.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/framework/src/FrameworkClasses.as 
b/frameworks/projects/framework/src/FrameworkClasses.as
index bb622d3..51e1c64 100644
--- a/frameworks/projects/framework/src/FrameworkClasses.as
+++ b/frameworks/projects/framework/src/FrameworkClasses.as
@@ -165,7 +165,6 @@ internal class FrameworkClasses
     import mx.utils.GetTimerUtil; GetTimerUtil;
     import mx.utils.HSBColor; HSBColor;
        import mx.utils.IOSPlatformVersionOverride; IOSPlatformVersionOverride;
-       import mx.utils.LegacyMobileThemeOverride; LegacyMobileThemeOverride;
     import mx.utils.LinkedList; LinkedList;
        import mx.utils.LinkedListNode; LinkedListNode;
        import mx.utils.OnDemandEventDispatcher; OnDemandEventDispatcher;

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/framework/src/mx/core/FlexVersion.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/framework/src/mx/core/FlexVersion.as 
b/frameworks/projects/framework/src/mx/core/FlexVersion.as
index bce991b..f99b634 100644
--- a/frameworks/projects/framework/src/mx/core/FlexVersion.as
+++ b/frameworks/projects/framework/src/mx/core/FlexVersion.as
@@ -56,21 +56,7 @@ public class FlexVersion
      *  @playerversion AIR 1.1
      *  @productversion Flex 3
      */
-    public static const CURRENT_VERSION:uint = 0x040F0000;
-       
-       /** 
-        *  The <code>compatibilityVersion</code> value of Flex 4.15,
-        *  encoded numerically as a <code>uint</code>.
-        *  Code can compare this constant against
-        *  the <code>compatibilityVersion</code>
-        *  to implement version-specific behavior.
-        *  
-        *  @langversion 3.0
-        *  @playerversion Flash 11
-        *  @playerversion AIR 3
-        *  @productversion Apache Flex 4.14
-        */
-       public static const VERSION_4_15:uint = 0x040F0000;
+    public static const CURRENT_VERSION:uint = 0x040E0000;
        
     /** 
      *  The <code>compatibilityVersion</code> value of Flex 4.14,

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/framework/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/framework/src/mx/core/Version.as 
b/frameworks/projects/framework/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/framework/src/mx/core/Version.as
+++ b/frameworks/projects/framework/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/framework/src/mx/resources/ResourceManagerImpl.as
----------------------------------------------------------------------
diff --git 
a/frameworks/projects/framework/src/mx/resources/ResourceManagerImpl.as 
b/frameworks/projects/framework/src/mx/resources/ResourceManagerImpl.as
index b5816a0..3e9c6fa 100644
--- a/frameworks/projects/framework/src/mx/resources/ResourceManagerImpl.as
+++ b/frameworks/projects/framework/src/mx/resources/ResourceManagerImpl.as
@@ -940,9 +940,6 @@ public class ResourceManagerImpl extends EventDispatcher 
implements IResourceMan
             findBundle(bundleName, resourceName, locale);
         if (!resourceBundle)
             return null;
-        
-        if(!(resourceName in resourceBundle.content))
-            return null;
 
         var value:String = String(resourceBundle.content[resourceName]);
         

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/framework/src/mx/utils/LegacyMobileThemeOverride.as
----------------------------------------------------------------------
diff --git 
a/frameworks/projects/framework/src/mx/utils/LegacyMobileThemeOverride.as 
b/frameworks/projects/framework/src/mx/utils/LegacyMobileThemeOverride.as
deleted file mode 100644
index 31e1621..0000000
--- a/frameworks/projects/framework/src/mx/utils/LegacyMobileThemeOverride.as
+++ /dev/null
@@ -1,47 +0,0 @@
-////////////////////////////////////////////////////////////////////////////////
-//
-//  Licensed to the Apache Software Foundation (ASF) under one or more
-//  contributor license agreements.  See the NOTICE file distributed with
-//  this work for additional information regarding copyright ownership.
-//  The ASF licenses this file to You under the Apache License, Version 2.0
-//  (the "License"); you may not use this file except in compliance with
-//  the License.  You may obtain a copy of the License at
-//
-//      http://www.apache.org/licenses/LICENSE-2.0
-//
-//  Unless required by applicable law or agreed to in writing, software
-//  distributed under the License is distributed on an "AS IS" BASIS,
-//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-//  See the License for the specific language governing permissions and
-//  limitations under the License.
-//
-////////////////////////////////////////////////////////////////////////////////
-
-package mx.utils
-{
-       
-       import flash.display.DisplayObject;
-       import flash.system.Capabilities;
-       
-       import mx.core.mx_internal;
-
-       [Mixin]
-       /**
-        * Set OS version to older values to force legacy mobile theme
-        */
-       public class LegacyMobileThemeOverride
-       {
-               public static function init(root:DisplayObject):void
-               {
-                       var c:Class = Capabilities;
-                       if(c.version.indexOf("AND") > -1)
-                       {
-                               Platform.mx_internal::androidVersionOverride =  
"2.0.0";
-                       }
-                       else if(c.version.indexOf("IOS") > -1)
-                       {
-                               Platform.mx_internal::iosVersionOverride =  
"6.0.0";
-                       }
-               }
-       }
-}
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/mobiletheme/defaults.css
----------------------------------------------------------------------
diff --git a/frameworks/projects/mobiletheme/defaults.css 
b/frameworks/projects/mobiletheme/defaults.css
index c4bed86..6264f08 100644
--- a/frameworks/projects/mobiletheme/defaults.css
+++ b/frameworks/projects/mobiletheme/defaults.css
@@ -101,7 +101,8 @@ ActionBar.beveled Group#actionGroup Button.emphasized
 
 BusyIndicator
 {
-       rotationInterval: 50;
+       skinClass: ClassReference("spark.skins.android4.BusyIndicatorSkin");
+       rotationInterval: 30;  /* Must be multiples of 30 */
 }
 
 Button

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/mx/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/mx/src/mx/core/Version.as 
b/frameworks/projects/mx/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/mx/src/mx/core/Version.as
+++ b/frameworks/projects/mx/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/rpc/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/rpc/src/mx/core/Version.as 
b/frameworks/projects/rpc/src/mx/core/Version.as
index 731653d..496ab63 100644
--- a/frameworks/projects/rpc/src/mx/core/Version.as
+++ b/frameworks/projects/rpc/src/mx/core/Version.as
@@ -22,4 +22,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/spark/src/spark/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/spark/src/spark/core/Version.as 
b/frameworks/projects/spark/src/spark/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/spark/src/spark/core/Version.as
+++ b/frameworks/projects/spark/src/spark/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/spark_dmv/src/spark/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/spark_dmv/src/spark/core/Version.as 
b/frameworks/projects/spark_dmv/src/spark/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/spark_dmv/src/spark/core/Version.as
+++ b/frameworks/projects/spark_dmv/src/spark/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/tool/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/tool/src/mx/core/Version.as 
b/frameworks/projects/tool/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/tool/src/mx/core/Version.as
+++ b/frameworks/projects/tool/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/frameworks/projects/tool_air/src/mx/core/Version.as
----------------------------------------------------------------------
diff --git a/frameworks/projects/tool_air/src/mx/core/Version.as 
b/frameworks/projects/tool_air/src/mx/core/Version.as
index f2edc26..647c056 100644
--- a/frameworks/projects/tool_air/src/mx/core/Version.as
+++ b/frameworks/projects/tool_air/src/mx/core/Version.as
@@ -23,4 +23,4 @@ import mx.core.mx_internal;
  *  @private
  *  Version string for this class.
  */
-mx_internal static const VERSION:String = "4.15.0.0";
+mx_internal static const VERSION:String = "4.14.0.0";

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/addAIRtoSDK.sh
----------------------------------------------------------------------
diff --git a/ide/addAIRtoSDK.sh b/ide/addAIRtoSDK.sh
index fcafcb3..97e1810 100755
--- a/ide/addAIRtoSDK.sh
+++ b/ide/addAIRtoSDK.sh
@@ -30,14 +30,14 @@
 AIR_VERSION="$1"
 OS=`uname`
 
-if [[ "${AIR_VERSION}" != "16.0" && "${AIR_VERSION}" != "15.0" 
+if [[ "${AIR_VERSION}" != "15.0" 
   && "${AIR_VERSION}" != "14.0" && "${AIR_VERSION}" != "13.0" && 
"${AIR_VERSION}" != "4.0" 
   && "${AIR_VERSION}" != "3.9" && "${AIR_VERSION}" != "3.8" && 
"${AIR_VERSION}" != "3.7" 
   && "${AIR_VERSION}" != "3.6" && "${AIR_VERSION}" != "3.5" && 
"${AIR_VERSION}" != "3.4" 
   && "${AIR_VERSION}" != "3.3" && "${AIR_VERSION}" != "3.2" && 
"${AIR_VERSION}" != "3.1" 
   && "${AIR_VERSION}" != "3.0" && "${AIR_VERSION}" != "2.7" && 
"${AIR_VERSION}" != "2.6" ]]
 then
-       echo Unknown version ${AIR_VERISON} of AIR. Versions 2.6, 2.7, 3.0, 
3.1, 3.2, 3.3, 3.4, 3.5, 3.6, 3.7, 3.8, 3.9, 4.0, 13.0, 14.0, 15.0 and 16.0 are 
supported.
+       echo Unknown version ${AIR_VERISON} of AIR. Versions 2.6, 2.7, 3.0, 
3.1, 3.2, 3.3, 3.4, 3.5, 3.6, 3.7, 3.8, 3.9, 4.0, 13.0, 14.0 and 15.0 are 
supported.
        exit 1;
 fi
 
@@ -98,11 +98,6 @@ downloadAIR()
        airTempDir="${IDE_SDK_DIR}/frameworks/temp"
        mkdir -p "${airTempDir}"
 
-       if [ ${AIR_VERSION} = "16.0" ]
-       then
-               
airDownload="http://labsdownload.adobe.com/pub/labs/flashruntimes/air/air16_sdk_sa_mac.tbz2";
-       fi      
-       
     if [[ "${OS}" == "Darwin" ]]
     then
         
airDownload="http://airdownload.adobe.com/air/mac/download/${version}/AdobeAIRSDK.tbz2";
@@ -161,13 +156,6 @@ for configFile in "${configFiles[@]}"
 do
        echo Updating ${configFile}
 
-       # 16.0 needs FP 16 and swf version 27
-       if [ ${AIR_VERSION} = "16.0" ]
-       then
-               updatePlayerVersion 16.0 "${configFile}"
-               updateSWFVersion 27 "${configFile}"
-       fi      
-       
        # 15.0 needs FP 15 and swf version 26
        if [ ${AIR_VERSION} = "15.0" ]
        then

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/checkAllPlayerGlobals.sh
----------------------------------------------------------------------
diff --git a/ide/checkAllPlayerGlobals.sh b/ide/checkAllPlayerGlobals.sh
index 84a2a47..27cbf62 100755
--- a/ide/checkAllPlayerGlobals.sh
+++ b/ide/checkAllPlayerGlobals.sh
@@ -108,20 +108,20 @@ agreeLicense
 
 # Note Adobe releases new versions of playerglobal.swf so if your checksum is 
wrong it may mean you just don't have the latest
 
-downloadPlayerGlobal 10.2 d51dba4e5e6bb72faffd9803d021bd7d 
http://download.macromedia.com/get/flashplayer/installers/archive/playerglobal/playerglobal10_2.swc
-downloadPlayerGlobal 10.3 8655be1b04af7109e46a0cb0d1be546e 
http://download.macromedia.com/get/flashplayer/installers/archive/playerglobal/playerglobal10_3.swc
-downloadPlayerGlobal 11.0 09ff39b8a7d946a49992674aff873c2d 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_0.swc
-downloadPlayerGlobal 11.1 70fec4b0b786965dc7bc413b9ee807f0 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
-downloadPlayerGlobal 11.2 7aa7b0d9e57186d4d92c5932f94d8b80 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_2.swc
-downloadPlayerGlobal 11.3 aaa2f1f31c7cdd6f5af2cda9ca63cd8f 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_3.swc
-downloadPlayerGlobal 11.4 f32d2e50d2bbfa1c1667425072a1b9ca 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_4.swc
-downloadPlayerGlobal 11.5 a1d9f6363aa1de5d07ca3002a2817da4 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_5.swc
-downloadPlayerGlobal 11.6 fa2441bdb8c823bc284ce96ec2198f26 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_6.swc
-downloadPlayerGlobal 11.7 78dae2a89297389079dc926852a2a9bc 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_7.swc
-downloadPlayerGlobal 11.8 cd0bead4aba52bc634df30d3e93196ba 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_8.swc
-downloadPlayerGlobal 11.9 463f60f1bf5006b37c48d49723c7c558 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_9.swc
-downloadPlayerGlobal 12.0 1a7b05bb2c776de38197113e40667126 
http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal12_0.swc
-downloadPlayerGlobal 13.0 07db042296350b04ae19e98f64a55ea1 
http://download.macromedia.com/get/flashplayer/updaters/13/playerglobal13_0.swc
-downloadPlayerGlobal 14.0 6858e63b1ff8373a1a3c1c60b36c9fc9 
http://download.macromedia.com/get/flashplayer/updaters/14/playerglobal14_0.swc
-downloadPlayerGlobal 15.0 4d17b14ef74dd23377a71a3fdbfda8ad 
http://download.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc
-downloadPlayerGlobal 16.0 f81045c8a6fdde1ed4952d6622355580 
http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer16_playerglobal.swc
+downloadPlayerGlobal 10.2 aa7d785dd5715626201f5e30fc1deb51 
http://download.macromedia.com/get/flashplayer/installers/archive/playerglobal/playerglobal10_2.swc
+downloadPlayerGlobal 10.3 6092b3d4e2784212d174ca10904412bd 
http://download.macromedia.com/get/flashplayer/installers/archive/playerglobal/playerglobal10_3.swc
+downloadPlayerGlobal 11.0 5f5a291f02105cd83fb582b76646e603 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_0.swc
+downloadPlayerGlobal 11.1 e3a0e0e8c703ae5b1847b8ac25bbdc5f 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
+downloadPlayerGlobal 11.2 c544a069518897880e0d732457b6fdeb 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_2.swc
+downloadPlayerGlobal 11.3 e2a9ee439d9660feaf756aa05e7e6412 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_3.swc
+downloadPlayerGlobal 11.4 e15587856cdb5e21fa1acb6b0610a032 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_4.swc
+downloadPlayerGlobal 11.5 00384b24157442c59ca5d625ecfd11a2 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_5.swc
+downloadPlayerGlobal 11.6 1b841a0a26ada3e5da26eb70c32ab263 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_6.swc
+downloadPlayerGlobal 11.7 12656571c57b2ad641838e5695a00e27 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_7.swc
+downloadPlayerGlobal 11.8 35bc69eec5091f70e221b4e63b66b60f 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_8.swc
+downloadPlayerGlobal 11.9 d18244c3c00c61a41f2d4d791d09fedb 
http://download.macromedia.com/get/flashplayer/updaters/11/playerglobal11_9.swc
+downloadPlayerGlobal 12.0 4db4e934f39f774ba68fcd9a79654971 
http://download.macromedia.com/get/flashplayer/updaters/12/playerglobal12_0.swc
+downloadPlayerGlobal 13.0 d40ea369a7fc2bcacc4cfcffff1339d4 
http://download.macromedia.com/get/flashplayer/updaters/13/playerglobal13_0.swc
+downloadPlayerGlobal 14.0 0bae2abfe34eed7d718eda123ec9e786 
http://download.macromedia.com/get/flashplayer/updaters/14/playerglobal14_0.swc
+downloadPlayerGlobal 15.0 051a72a4be1e02894dca0c2c01d8d8e2 
http://download.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc
+

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/constructFlexForIDE.sh
----------------------------------------------------------------------
diff --git a/ide/constructFlexForIDE.sh b/ide/constructFlexForIDE.sh
index d9533ab..1d1af97 100755
--- a/ide/constructFlexForIDE.sh
+++ b/ide/constructFlexForIDE.sh
@@ -155,8 +155,6 @@ files=(
     "AIR SDK Readme.txt" 
     bin/adl.exe 
     bin/adt.bat 
-    bin/adl
-    bin/adt
     frameworks/libs/air
     frameworks/libs/player/11.1
     frameworks/projects/air

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/flashbuilder/config/air-config.xml
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/config/air-config.xml 
b/ide/flashbuilder/config/air-config.xml
index 2887c63..2df10ab 100644
--- a/ide/flashbuilder/config/air-config.xml
+++ b/ide/flashbuilder/config/air-config.xml
@@ -353,7 +353,7 @@
       <!-- Framework SWC -->
        <runtime-shared-library-path>
                <path-element>libs/framework.swc</path-element>
-               <rsl-url>framework_4.14.0.0.swf</rsl-url>
+               <rsl-url>framework_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
          
          <!-- TextLayout SWC -->
@@ -363,37 +363,37 @@
     -->
     <runtime-shared-library-path>
                <path-element>libs/textLayout.swc</path-element>
-               <rsl-url>textLayout_4.14.0.0.swf</rsl-url>
+               <rsl-url>textLayout_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
     
       <!-- Spark SWC-->
        <runtime-shared-library-path>
                <path-element>libs/spark.swc</path-element>
-               <rsl-url>spark_4.14.0.0.swf</rsl-url>
+               <rsl-url>spark_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
        
       <!-- Sparkskins SWC-->
        <runtime-shared-library-path>
                <path-element>libs/sparkskins.swc</path-element>
-               <rsl-url>sparkskins_4.14.0.0.swf</rsl-url>
+               <rsl-url>sparkskins_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
         
          <!-- RPC SWC -->
        <runtime-shared-library-path>
                <path-element>libs/rpc.swc</path-element>
-               <rsl-url>rpc_4.14.0.0.swf</rsl-url>
+               <rsl-url>rpc_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
        
       <!-- Charts SWC -->
        <runtime-shared-library-path>
                <path-element>libs/charts.swc</path-element>
-               <rsl-url>charts_4.14.0.0.swf</rsl-url>
+               <rsl-url>charts_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- Spark_dmv SWC -->
        <runtime-shared-library-path>
                <path-element>libs/spark_dmv.swc</path-element>
-               <rsl-url>spark_dmv_4.14.0.0.swf</rsl-url>
+               <rsl-url>spark_dmv_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- OSMF SWC -->
@@ -403,19 +403,19 @@
     -->
     <runtime-shared-library-path>
                <path-element>libs/osmf.swc</path-element>
-               <rsl-url>osmf_4.14.0.0.swf</rsl-url>
+               <rsl-url>osmf_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
       
       <!-- MX SWC -->
        <runtime-shared-library-path>
                <path-element>libs/mx/mx.swc</path-element>
-               <rsl-url>mx_4.14.0.0.swf</rsl-url>
+               <rsl-url>mx_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
    
       <!-- Advancedgrids SWC -->
        <runtime-shared-library-path>
                <path-element>libs/advancedgrids.swc</path-element>
-               <rsl-url>advancedgrids_4.14.0.0.swf</rsl-url>
+               <rsl-url>advancedgrids_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
        
     <!-- static-link-runtime-shared-libraries: statically link the libraries 
specified by the -runtime-shared-libraries-path option.-->

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/flashbuilder/config/flex-config.xml
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/config/flex-config.xml 
b/ide/flashbuilder/config/flex-config.xml
index cb89647..1536d4a 100644
--- a/ide/flashbuilder/config/flex-config.xml
+++ b/ide/flashbuilder/config/flex-config.xml
@@ -357,7 +357,7 @@
       <!-- Framework SWC -->
        <runtime-shared-library-path>
                <path-element>libs/framework.swc</path-element>
-               <rsl-url>framework_4.14.0.0.swf</rsl-url>
+               <rsl-url>framework_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
          <!-- TextLayout SWC -->
@@ -367,37 +367,37 @@
     -->
     <runtime-shared-library-path>
                <path-element>libs/textLayout.swc</path-element>
-               <rsl-url>textLayout_4.14.0.0.swf</rsl-url>
+               <rsl-url>textLayout_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- Spark SWC-->
        <runtime-shared-library-path>
                <path-element>libs/spark.swc</path-element>
-               <rsl-url>spark_4.14.0.0.swf</rsl-url>
+               <rsl-url>spark_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- Sparkskins SWC-->
        <runtime-shared-library-path>
                <path-element>libs/sparkskins.swc</path-element>
-               <rsl-url>sparkskins_4.14.0.0.swf</rsl-url>
+               <rsl-url>sparkskins_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
          <!-- RPC SWC -->
        <runtime-shared-library-path>
                <path-element>libs/rpc.swc</path-element>
-               <rsl-url>rpc_4.14.0.0.swf</rsl-url>
+               <rsl-url>rpc_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- Charts SWC -->
        <runtime-shared-library-path>
                <path-element>libs/charts.swc</path-element>
-               <rsl-url>charts_4.14.0.0.swf</rsl-url>
+               <rsl-url>charts_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- Spark_dmv SWC -->
        <runtime-shared-library-path>
                <path-element>libs/spark_dmv.swc</path-element>
-               <rsl-url>spark_dmv_4.14.0.0.swf</rsl-url>
+               <rsl-url>spark_dmv_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- OSMF SWC -->
@@ -406,20 +406,20 @@
            Flex Library project, FlashBuilder will allow "Link Type" to be 
external.
     -->
     <runtime-shared-library-path>
-               <path-element>libs/osmf.swc</path-element>
-               <rsl-url>osmf_4.14.0.0.swf</rsl-url>
+               <path-element>libs/OSMF.swc</path-element>
+               <rsl-url>osmf_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- MX SWC -->
        <runtime-shared-library-path>
                <path-element>libs/mx/mx.swc</path-element>
-               <rsl-url>mx_4.14.0.0.swf</rsl-url>
+               <rsl-url>mx_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
       <!-- Advancedgrids SWC -->
        <runtime-shared-library-path>
                <path-element>libs/advancedgrids.swc</path-element>
-               <rsl-url>advancedgrids_4.14.0.0.swf</rsl-url>
+               <rsl-url>advancedgrids_4.13.0.0.swf</rsl-url>
        </runtime-shared-library-path>
 
        <!-- static-link-runtime-shared-libraries: statically link the 
libraries specified by the -runtime-shared-libraries-path option.-->

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/flashbuilder/makeApacheFlexForIDE.bat
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.bat 
b/ide/flashbuilder/makeApacheFlexForIDE.bat
index a00e598..8b31a34 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.bat
+++ b/ide/flashbuilder/makeApacheFlexForIDE.bat
@@ -42,10 +42,10 @@ REM
 set APACHE_FLEX_BIN_DISTRO_DIR=..\..
 
 REM
-REM     Adobe AIR SDK Version 15.0
+REM     Adobe AIR SDK Version 13.0
 REM
 set ADOBE_AIR_SDK_WIN_FILE=AdobeAIRSDK.zip
-set 
ADOBE_AIR_SDK_WIN_URL=http://airdownload.adobe.com/air/win/download/15.0/%ADOBE_AIR_SDK_WIN_FILE%
+set 
ADOBE_AIR_SDK_WIN_URL=http://airdownload.adobe.com/air/win/download/13.0/%ADOBE_AIR_SDK_WIN_FILE%
 
 REM
 REM     Adobe Flash Player Version 11.1
@@ -53,9 +53,9 @@ REM
 set 
ADOBE_FB_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
 
 REM
-REM     Adobe Flash Player Version 15.0
+REM     Adobe Flash Player Version 13.0
 REM
-set 
ADOBE_FB_GLOBALPLAYER_15_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal15_0.swc
+set 
ADOBE_FB_GLOBALPLAYER_13_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal13_0.swc
 
 :getDir
 if not [%1] == [] goto checkJar
@@ -124,13 +124,13 @@ cscript //B //nologo winUtil.vbs 
"%ADOBE_FB_GLOBALPLAYER_11_1_SWC_URL%" "%FB_GLO
 if %errorlevel% neq 0 goto errorExit
 
 REM
-REM     Download 15.0 playerglobal.swc
+REM     Download 13.0 playerglobal.swc
 REM
-set FB_GLOBALPLAYER_DIR=%FLEX_HOME%\frameworks\libs\player\15.0
+set FB_GLOBALPLAYER_DIR=%FLEX_HOME%\frameworks\libs\player\13.0
 if not exist "%FB_GLOBALPLAYER_DIR%" mkdir "%FB_GLOBALPLAYER_DIR%"
 
-echo Downloading Adobe Flash Player playerglobal.swc from 
"%ADOBE_FB_GLOBALPLAYER_15_0_SWC_URL%" to 
"%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
-cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_15_0_SWC_URL%" 
"%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
+echo Downloading Adobe Flash Player playerglobal.swc from 
"%ADOBE_FB_GLOBALPLAYER_13_0_SWC_URL%" to 
"%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
+cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_13_0_SWC_URL%" 
"%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
 if %errorlevel% neq 0 goto errorExit
 
 REM

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/flashbuilder/makeApacheFlexForIDE.sh
----------------------------------------------------------------------
diff --git a/ide/setFlashPlayerVersion.sh b/ide/setFlashPlayerVersion.sh
index 8bcf77e..b76f2ef 100755
--- a/ide/setFlashPlayerVersion.sh
+++ b/ide/setFlashPlayerVersion.sh
@@ -99,18 +99,18 @@ determineVersion()
         then 
             FLASH_VERSION="11.1"
         else
-            FLASH_VERSION="15.0"
+            FLASH_VERSION="14.0"
         fi
     fi
     
     if [ ${latest} = "Y" ]
     then
-       FLASH_VERSION="15.0"
+       FLASH_VERSION="14.0"
     fi
     
     if [ ${useBeta} = "Y" ]
     then
-       FLASH_VERSION="16.0"
+       FLASH_VERSION="14.0"
     fi
     
     echo "Setting minimum Flash Player version to ${FLASH_VERSION}"
@@ -128,9 +128,9 @@ if [[ "${FLASH_VERSION}" != "10.2" && "${FLASH_VERSION}" != 
"10.3"  && "${FLASH_
   && "${FLASH_VERSION}" != "11.4" && "${FLASH_VERSION}" != "11.5" && 
"${FLASH_VERSION}" != "11.6"
   && "${FLASH_VERSION}" != "11.7" && "${FLASH_VERSION}" != "11.8" && 
"${FLASH_VERSION}" != "11.9"
   && "${FLASH_VERSION}" != "12.0" && "${FLASH_VERSION}" != "13.0" && 
"${FLASH_VERSION}" != "14.0"
-  && "${FLASH_VERSION}" != "15.0" && "${FLASH_VERSION}" != "16.0" ]]
+  && "${FLASH_VERSION}" != "15.0" ]]
 then
-       echo Unknown version ${FLASH_VERSION} of Flash Player. Versions 10.2, 
10.3, 11.0, 11.1, 11.2, 11.3, 11.4, 11.5, 11.6, 11.7, 11.8, 11.9, 12.0, 13.0, 
14.0, 15.0 and 16.0 are supported.
+       echo Unknown version ${FLASH_VERSION} of Flash Player. Versions 10.2, 
10.3, 11.0, 11.1, 11.2, 11.3, 11.4, 11.5, 11.6, 11.7, 11.8, 11.9, 12.0, 13.0, 
14.0 and 15.0 are supported.
        exit 1;
 fi
 
@@ -150,16 +150,6 @@ if [[ $useMobile = "Y" || $useDesktop = "Y" ]]
 then
        echo Installing AIR
        echo
-       
-       if [[ $FLASH_VERSION = "16.0" ]]
-    then
-        ./addAIRtoSDK.sh 16.0 "$IDE_SDK_DIR"
-    fi
-    
-       if [[ $FLASH_VERSION = "15.0" ]]
-    then
-        ./addAIRtoSDK.sh 15.0 "$IDE_SDK_DIR"
-    fi
 
        if [[ $FLASH_VERSION = "14.0" ]]
     then
@@ -234,16 +224,6 @@ do
        
        updatePlayerVersion "${FLASH_VERSION}" "${configFile}"
 
-       if [ ${FLASH_VERSION} = "16.0" ]
-       then
-               updateSWFVersion 27 "${configFile}"
-       fi
-       
-       if [ ${FLASH_VERSION} = "15.0" ]
-       then
-               updateSWFVersion 26 "${configFile}"
-       fi
-       
        if [ ${FLASH_VERSION} = "14.0" ]
        then
                updateSWFVersion 25 "${configFile}"

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/jenkins.xml
----------------------------------------------------------------------
diff --git a/jenkins.xml b/jenkins.xml
index 3ea47ae..f51cdc3 100644
--- a/jenkins.xml
+++ b/jenkins.xml
@@ -101,15 +101,6 @@
                <condition property="target13.0">
                        <equals arg1="${playerglobal.version}" arg2="13.0" />
                </condition>
-               <condition property="target14.0">
-                       <equals arg1="${playerglobal.version}" arg2="14.0" />
-               </condition>
-               <condition property="target15.0">
-                       <equals arg1="${playerglobal.version}" arg2="15.0" />
-               </condition>
-               <condition property="target16.0">
-                       <equals arg1="${playerglobal.version}" arg2="16.0" />
-               </condition>
         </target>
 
     <target name="playerglobal10.2-download" if="target10.2">
@@ -205,28 +196,7 @@
                
     <target name="playerglobal13.0-download" if="target13.0">
        <mkdir dir="${basedir}/lib/player/${playerglobal.version}"/>
-        <get 
src="http://download.macromedia.com/get/flashplayer/updaters/13/playerglobal13_0.swc";
 
-            
dest="${basedir}/lib/player/${playerglobal.version}/playerglobal.swc" 
-            verbose="false"/>
-    </target>
-       
-    <target name="playerglobal14.0-download" if="target14.0">
-       <mkdir dir="${basedir}/lib/player/${playerglobal.version}"/>
-        <get 
src="http://download.macromedia.com/get/flashplayer/updaters/14/playerglobal14_0.swc";
 
-            
dest="${basedir}/lib/player/${playerglobal.version}/playerglobal.swc" 
-            verbose="false"/>
-    </target>
-       
-    <target name="playerglobal15.0-download" if="target15.0">
-       <mkdir dir="${basedir}/lib/player/${playerglobal.version}"/>
-        <get 
src="http://download.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc";
 
-            
dest="${basedir}/lib/player/${playerglobal.version}/playerglobal.swc" 
-            verbose="false"/>
-    </target>
-
-    <target name="playerglobal16.0-download" if="target16.0">
-       <mkdir dir="${basedir}/lib/player/${playerglobal.version}"/>
-        <get 
src="http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer16_playerglobal.swc";
 
+        <get 
src="http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer13_playerglobal.swc";
 
             
dest="${basedir}/lib/player/${playerglobal.version}/playerglobal.swc" 
             verbose="false"/>
     </target>

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/modules/compiler/src/java/flex2/compiler/common/MxmlConfiguration.java
----------------------------------------------------------------------
diff --git 
a/modules/compiler/src/java/flex2/compiler/common/MxmlConfiguration.java 
b/modules/compiler/src/java/flex2/compiler/common/MxmlConfiguration.java
index fea12b6..228a50b 100644
--- a/modules/compiler/src/java/flex2/compiler/common/MxmlConfiguration.java
+++ b/modules/compiler/src/java/flex2/compiler/common/MxmlConfiguration.java
@@ -48,7 +48,6 @@ public class MxmlConfiguration
     //
     // 'compiler.mxml.compatibility-version' option
     //
-    public static final int VERSION_4_15 = 0x040f0000;
        public static final int VERSION_4_14 = 0x040e0000;
        public static final int VERSION_4_13 = 0x040d0000;
        public static final int VERSION_4_12_1 = 0x040c0001;
@@ -64,10 +63,10 @@ public class MxmlConfiguration
     public static final int VERSION_3_0 = 0x03000000;
     public static final int VERSION_2_0_1 = 0x02000001;
     public static final int VERSION_2_0 = 0x02000000;
-    public static final int CURRENT_VERSION = VERSION_4_15;
+    public static final int CURRENT_VERSION = VERSION_4_14;
     public static final int EARLIEST_MAJOR_VERSION = 3;
     public static final int LATEST_MAJOR_VERSION = 4;
-    public static final int LATEST_MINOR_VERSION = 15;
+    public static final int LATEST_MINOR_VERSION = 14;
 
        private int major = LATEST_MAJOR_VERSION;
        private int minor = LATEST_MINOR_VERSION;

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/modules/compiler/src/java/flex2/tools/VersionInfo.java
----------------------------------------------------------------------
diff --git a/modules/compiler/src/java/flex2/tools/VersionInfo.java 
b/modules/compiler/src/java/flex2/tools/VersionInfo.java
index c90f66d..8d7db5d 100644
--- a/modules/compiler/src/java/flex2/tools/VersionInfo.java
+++ b/modules/compiler/src/java/flex2/tools/VersionInfo.java
@@ -32,7 +32,7 @@ import java.util.Properties;
 public class VersionInfo
 {
     public static String FLEX_MAJOR_VERSION = "4";
-    public static String FLEX_MINOR_VERSION = "15";
+    public static String FLEX_MINOR_VERSION = "14";
     public static String FLEX_NANO_VERSION  = "0";
     
        /**

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/mustella/jenkins.sh
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.sh 
b/ide/flashbuilder/makeApacheFlexForIDE.sh
index a0b3af3..fc34d52 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.sh
+++ b/ide/flashbuilder/makeApacheFlexForIDE.sh
@@ -38,12 +38,12 @@
 # Apache Flex binary distribution
 APACHE_FLEX_BIN_DIR="$( cd $( dirname -- "$0" ) > /dev/null ; pwd )"/../..
 
-# Adobe AIR SDK Version 15.0
-ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/15.0/AdobeAIRSDK.tbz2
+# Adobe AIR SDK Version 14.0
+ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/14.0/AdobeAIRSDK.tbz2
 
 # Adobe Flash Player Version 11.1
 
ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
-ADOBE_FLASHPLAYER_GLOBALPLAYER_15_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc
+ADOBE_FLASHPLAYER_GLOBALPLAYER_14_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/14/playerglobal14_0.swc
 
 # Adobe Flex SDK v4.6
 
ADOBE_FLEX_SDK_URL=http://fpdownload.adobe.com/pub/flex/sdk/builds/flex4.6/flex_sdk_4.6.0.23201B.zip
@@ -104,10 +104,10 @@ echo "Downloading Adobe Flash Player playerglobal.swc 
from $ADOBE_FLASHPLAYER_GL
 mkdir -p "$FLEX_HOME/frameworks/libs/player/11.1"
 curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL" --output 
"$FLEX_HOME/frameworks/libs/player/11.1/playerglobal.swc"
 
-# download 15 playerglobal.swc
-echo "Downloading Adobe Flash Player playerglobal.swc from 
$ADOBE_FLASHPLAYER_GLOBALPLAYER_15_0_SWC_URL"
-mkdir -p "$FLEX_HOME/frameworks/libs/player/15.0"
-curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_15_0_SWC_URL" --output 
"$FLEX_HOME/frameworks/libs/player/15.0/playerglobal.swc"
+# download 14 playerglobal.swc
+echo "Downloading Adobe Flash Player playerglobal.swc from 
$ADOBE_FLASHPLAYER_GLOBALPLAYER_14_0_SWC_URL"
+mkdir -p "$FLEX_HOME/frameworks/libs/player/14.0"
+curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_14_0_SWC_URL" --output 
"$FLEX_HOME/frameworks/libs/player/14.0/playerglobal.swc"
 
 # copy the config files formatted for Flash Builder to frameworks 
 echo "Installing the frameworks config files configured for use with Adobe 
Flash Builder"

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/ide/setFlashPlayerVersion.sh
----------------------------------------------------------------------
diff --git a/mustella/jenkins.sh b/mustella/jenkins.sh
index 7757ac5..6614b16 100755
--- a/mustella/jenkins.sh
+++ b/mustella/jenkins.sh
@@ -51,7 +51,7 @@ fi
 # 11.1 is the default version
 # 11.7 is a much used version?
 # 13 is the current "long term support" version
 # 16 is the beta and/or current version
 # Note: the previous release and current beta versions of AIR are both '4',
 #       so to make the distinction, the beta version is '4.01' on the VM
 if [ "$FLASH_VERSION" == "11.1" ]
@@ -66,9 +66,9 @@ then
   AIR_SDK_DIR=4.0
 elif [ "$FLASH_VERSION" == "13.0" ]
 then
-  FLASH_VERSION=16.0
-  AIR_VERSION=16
-  AIR_SDK_DIR=16
+  FLASH_VERSION=15.0
+  AIR_VERSION=15
+  AIR_SDK_DIR=15
 else
   FLASH_VERSION=11.1
   AIR_VERSION=3.7
@@ -93,8 +93,8 @@ case "$FLASH_VERSION" in
   13.0)
     export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer13_0r0_214_win_sa_debug.exe"
   ;;
-  16.0)
-    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer_16_sa_debug.exe"
+  15.0)
+    export 
FLASHPLAYER_DEBUGGER="C:\\ApacheFlex\\dependencies\\FlashPlayer_Debug\\flashplayer_15_sa_debug.exe"
   ;;
   *)
     echo "No valid Flash Player Debugger variable value could be parsed."

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/fef7f068/mustella/tests/resources/ResourceManager/Methods/ResourceManager_Methods_getString.mxml
----------------------------------------------------------------------
@@ -51,7 +51,7 @@ fi
 # 11.7 is a much used version?
 # 13 is the current "long term support" version
-# 16 is the beta and/or current version
+# 15 is the current 'beta' version
 # Note: the previous release and current beta versions of AIR are both '4',
 #       so to make the distinction, the beta version is '4.01' on the VM
diff --git 
a/mustella/tests/resources/ResourceManager/Methods/ResourceManager_Methods_getString.mxml
 
b/mustella/tests/resources/ResourceManager/Methods/ResourceManager_Methods_getString.mxml
index 43b74dd..ce97954 100644
--- 
a/mustella/tests/resources/ResourceManager/Methods/ResourceManager_Methods_getString.mxml
+++ 
b/mustella/tests/resources/ResourceManager/Methods/ResourceManager_Methods_getString.mxml
@@ -65,19 +65,6 @@
                                <Pause timeout="1"/>
                        </body>
                </TestCase>
-        
-        <TestCase frequency="all" 
testID="ResourceManager_getString_NO_SUCH_KEY_withLocale_FLEX25045" 
description="Tests that the getString() method of ResourceManager returns null 
when accessing a non-existent resource but a valid locale reference" 
keywords="[resources,ResourceManager,getString]">
-            <setup>
-                <RunCode code="application.setup()"/>
-                <RunCode code="application.doAddResourceBundle('fr_FR', 
'bundle1')" />
-
-                <RunCode code="ResourceManager.getInstance().localeChain = 
['fr_FR']" />
-            </setup>
-            <body>
-                <AssertMethodValue method="value=testGetString('NO_SUCH_KEY', 
null, null, 'fr_FR')" value="true"/>
-                <Pause timeout="1"/>
-            </body>
-        </TestCase>
 
                <TestCase frequency="all" 
testID="ResourceManager_getString_STRING" description="Tests the getString() 
method of ResourceManager for a resource value which is a typical String" 
keywords="[resources,ResourceManager,getString]">
                        <setup>

Reply via email to